@@ -85,10 +85,12 @@ class Point:
     def __init__(self,
                  user: Union[int, User, None],
                  query_params: Union[None, dict] = None,
+                 action: str = None,
                  is_async: bool = False,
                  timeout: tuple = (30, 30)
                  ):
         self._user = user if user is None or isinstance(user, User) else User.objects.get(id=user)
+        self._action = action
         self._cache = None
         self._response = None
         self._is_async = is_async
@@ -113,7 +115,10 @@ class Point:
 
     @property
     def _path(self):
-        path = self._point_id.path
+        if self._action is None:
+            path = self._point_id.path
+        else:
+            path = f'{self._point_id.path}/{self._action}'
         return path
 
     def _post(self, payload: dict):
